Tr64Service class
Base class for TR-064 service wrappers.
Subclasses represent specific TR-064 services (e.g. DeviceInfo) and provide typed action methods.
Constructors
- Tr64Service({required ServiceDescription description, required SoapActionCallback callAction, required FetchUrlCallback fetchUrl})
Properties
- controlUrl → String
-
no setter
- description → ServiceDescription
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceType → String
-
no setter
Methods
-
call(
String actionName, [Map< String, String> arguments = const {}]) → Future<Map< String, String> > - Call a SOAP action on this service and return the response arguments.
-
fetchUrl(
String url) → Future< String> - Fetch a URL and return the response body.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited